Index — mit_moira 0.0.2 documentation

# Index

A | C | L | M | P | U

## A

add_member_to_list() (mit_moira.Moira method)

## C

client (mit_moira.Moira attribute) | create_list() (mit_moira.Moira method)

## L

list_attributes() (mit_moira.Moira method) | list_exists() (mit_moira.Moira method) list_members() (mit_moira.Moira method)

## M

mit_moira (module) | Moira (class in mit_moira)

## P

print_capabilities() (mit_moira.Moira method)

## U

update_list() (mit_moira.Moira method) | user_lists() (mit_moira.Moira method)